//所有的网络数据请求
angular.module("starter.apiService", [])
  .service("apiService", function ($http, $q, Constants) {
    //获取广告列表
    this.getAdsList = function () {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getAdsList',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
          //'Content-Type': 'application/json'
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取首页问题列表
     * @param pageNum  页码
     * @param lastTime 时间戳
     * @returns {Promise}
     */
    this.getHomePageQuestionList = function (userId, pageNum, lastTime) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getHomePageQuestionList',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "pageNum": pageNum,
          "lastTime": lastTime,
          "userId": userId
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }
    /**
     * 获取问题详情(老师端我答问题详情页面)
     * @param userId 用户id
     * @param questionId 问题id
     * @returns {Promise}
     */
    this.getQuestionInfo = function (userId, questionId) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getQuestionInfo',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "questionId": questionId
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取提问列表
     * @param userId 用户ID 未登录传""
     * @param teacherId 老师ID
     * @param flagNew 最新/热门区分 0:最新 1:热门
     * @param flagMy 我的问题 0:我问的 1:我听的 2:我答的
     * @param flagStatus 问题状态 0:未回答 1:已回答 2:已过期
     * @param pageNum 页码
     * @param lastTime 时间戳
     * @param search 搜索内容
     * @param flag 区分flag 0:最新/最热 1:导师详情 2:导师 3:自己
     * @returns {Promise}
     */
    this.getQustionList = function (userId, teacherId, flagNew, flagMy, flagStatus, pageNum, lastTime, search, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getQustionList',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/json'
        },
        data: {
          "userId": userId,
          "teacherId": teacherId,
          "flagNew": flagNew,
          "flagMy": flagMy,
          "flagStatus": flagStatus,
          "pageNum": pageNum,
          "lastTime": lastTime,
          "search": search,
          "flag": flag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }
    /**
     * 获取信息列表
     * @param userId 用户ID 未登录传""
     * @param mutiType 信息类型 01：眼界 02：课堂 03：榜样 09：其他
     * @param flagMy 我的 0:我的 1:其它
     * @param pageNum 页码
     * @param lastTime 时间戳
     * @param searchContent 搜索内容
     * @returns {Promise}
     */
    this.getMutiList = function (userId, mutiType, flagMy, pageNum, lastTime, searchContent) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMutiList',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/json'
        },
        data: {
          "userId": userId,
          "mutiType": mutiType,
          "flagMy": flagMy,
          "pageNum": pageNum,
          "lastTime": lastTime,
          "searchContent": searchContent
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /***
     * 获取信息详情
     * @param userId 用户ID
     * @param mutiId 信息id
     * @returns {Promise}
     */
    this.getMutiInfo = function (userId, mutiId) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMutiInfo',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "mutiId": mutiId
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     *  提问
     * @param userId 用户id
     * @param teacherId 导师id
     * @param questionInfo 问题内容
     * @param questionFee 提问费用
     * @param questionTime 提问时间
     * @param questionOpenFlag 问题公开区分 0:私密 1:公开
     * @returns {Promise}
     */
    this.doQuestion = function (userId, teacherId, questionInfo, questionFee, questionTime, questionOpenFlag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'doQuestion',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "teacherId": teacherId,
          "questionInfo": questionInfo,
          "questionFee": questionFee,
          "questionTime": questionTime,
          "questionOpenFlag": questionOpenFlag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取导师列表
     * @param pageNum 页码
     * @param lastTime 时间戳
     * @param searchContent 搜索内容
     * @returns {Promise}
     */

    this.getTeacherList = function (pageNum, lastTime, searchContent) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getTeacherList',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "pageNum": pageNum,
          "lastTime": lastTime,
          "searchContent": searchContent
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取导师详情
     * @param teacherId 导师id
     * @param userId 用户id
     * @param flag 区分 0:导师 1:自己
     * @returns {Promise}
     */
    this.getTeacherInfo = function (userId, teacherId, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getTeacherInfo',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "teacherId": teacherId,
          "userId": userId,
          "flag": flag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取我的主页信息
     * @param userId 用户id
     * @param flag 角色区分 0:老师 1:个人
     * @returns {Promise}
     */
    this.getMyHomePage = function (userId, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMyHomePage',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "flag": flag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取我的收藏信息
     * @param userId 用户id
     * @param pageNum 当前页数
     * @param lastTime 最后更新时间
     * @returns {Promise}
     */
    this.getMyCollect = function (userId, pageNum, lastTime) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMyCollect',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "pageNum": pageNum,
          "lastTime": lastTime
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取我的评价信息
     * @param userId 用户id
     * @param pageNum 当前页数
     * @param lastTime 最后更新时间
     * @returns {Promise}
     */
    this.getMyAppraise = function (userId, pageNum, lastTime) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMyAppraise',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "pageNum": pageNum,
          "lastTime": lastTime
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取信息评论列表
     * @param mutiId 信息id
     * @param pageNum 页码
     * @param lastTime 时间戳
     * @returns {Promise}
     */
    this.getMutiCommentList = function (mutiId, pageNum, lastTime) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMutiCommentList',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "mutiId": mutiId,
          "pageNum": pageNum,
          "lastTime": lastTime
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 注册
     * @param loginInfo 手机号码
     * @param password 密码
     * @param nickName 昵称
     * @param userImg 用户头像
     * @param signature 个性签名
     * @param gender 性别
     * @param locationId 所在地Id
     * @param age 年龄
     * @returns {Promise}
     */
    this.register = function (loginInfo, password, nickName, userImg, signature, gender, locationId, age) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'register',
        method: 'POST',
        timeout: Constants.timeout,
        data: {
          "loginInfo": loginInfo,
          "password": password,
          "nickName": nickName,
          "userImg": userImg,
          "signature": signature,
          "gender": gender,
          "locationId": locationId,
          "age": age
        },
        headers: {
          'Content-Type': undefined
        },
        transformRequest: function (data) {
          var formData = new FormData();
          formData.append('loginInfo', data.loginInfo);
          formData.append('password', data.password);
          formData.append('nickName', data.nickName);
          formData.append('userImg', data.userImg);
          formData.append('signature', data.signature);
          formData.append('gender', data.gender);
          formData.append('locationId', data.locationId);
          formData.append('age', data.age);
          return formData;
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 登陆
     * @param loginInfo 手机号码
     * @param password 登录密码 加密后的密码MD5
     * @returns {Promise}
     */
    this.login = function (loginInfo, password) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'login',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "loginInfo": loginInfo,
          "password": password
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 三方登陆
     * @param accountType 授权类型 01：新浪微博；02：微信；03：QQ腾讯 04：faceBook
     * @param uid 用户标识
     * @param accessToken 授权码
     * @param refreshToken 刷新授权码
     * @param gender 性别 0：男 1：女
     * @param userImgUrl 头像地址
     * @param nickname 昵称
     * @param fwhOpenId 微信服务号标识
     * @param appOpenId 微信APP标号
     * @returns {Promise}
     */
    this.thirdLogin = function (accountType, uid, accessToken, refreshToken, gender, userImgUrl, nickname, fwhOpenId, appOpenId) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'thirdLogin',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "accountType": accountType,
          "uid": uid,
          "accessToken": accessToken,
          "refreshToken": refreshToken,
          "gender": gender,
          "userImgUrl": userImgUrl,
          "nickname": nickname,
          "fwhOpenId": fwhOpenId,
          "appOpenId": appOpenId
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 发送短信
     * @param icode 验证码
     * @param phoneNumber 手机号码
     * @param sign 验证内容 用（手机号&验证码）MD5加密后的内容
     * @param flag 判断注册还是找回密码 0:注册 1:移动端找回密码 2:web端找回密码
     * @returns {Promise}
     */
    this.sendSMS = function (icode, phoneNumber, sign, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'sendSMS',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "icode": icode,
          "phoneNumber": phoneNumber,
          "sign": sign,
          "flag": flag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 修改/找回密码
     * @param loginInfo 手机号码
     * @param newPassword 新密码
     * @param oldPassword 旧密码
     * @param optType 操作类型 0：修改密码；1：找回密码(找回密码时，新密码传重新设置的密码值，旧密码传xx)
     * @returns {Promise}
     */
    this.updPassword = function (loginInfo, newPassword, oldPassword, optType) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'updPassword',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "loginInfo": loginInfo,
          "newPassword": newPassword,
          "oldPassword": oldPassword,
          "optType": optType
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取微信的access_token
     * @param code
     * @returns {Promise}
     */

    this.getWechatJsSdkSign = function (url) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getWechatJsSdkSign',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "url": url
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    this.wechatLogin = function (code) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'wechat/WXPageLogin',
        method: 'POST',
        timeout: Constants.timeout,
        params: {
          "code": code
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 支付
     * @param userId 用户ID
     * @param questionId 拼接后的问题ID
     * @param flag 支付区分 0:提问 1：偷听
     * @returns {Promise}
     */
    this.pay = function (userId, questionId, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'pay',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "questionId": questionId,
          "flag": flag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 支付查询
     * @param userId 用户ID
     * @param questionId 拼接后的问题ID
     * @param flag 支付区分 0:提问 1：偷听
     * @returns {Promise}
     */
    this.search = function (userId, questionId, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'search',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "questionId": questionId,
          "flag": flag
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 微信支付查询
     * @param orderId
     * @returns {Promise}
     */
    this.searchWXPay = function (orderId) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'searchWXPay',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "orderId": orderId
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取配置的系统信息
     * @returns {Promise}
     */
    this.getSysInfo = function () {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getSysInfo',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          "user-appid": 'html5',
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 更新个人信息
     * @param userId 用户id
     * @param userName 用户昵称
     * @param profiles 简介
     * @param userImg 用户头像
     * @param userPhone 手机号码
     * @param gender 性别 0:男 1:女
     * @param locationId 城市
     * @param age 年龄段
     * @param flag 区分完善/编辑 0:完善 1:编辑
     * @returns {Promise}
     */
    this.updUserInfo = function (userId, userName, profiles, userImg, userPhone, gender, locationId, age, flag) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'updUserInfo',
        method: 'POST',
        timeout: Constants.timeout,
        data: {
          "userId": userId,
          "userName": userName,
          "profiles": profiles,
          "userImg": userImg,
          "userPhone": userPhone,
          "gender": gender,
          "locationId": locationId,
          "age": age,
          "flag": flag
        },
        headers: {
          'Content-Type': undefined
        },
        transformRequest: function (data) {
          var formData = new FormData();
          formData.append('userId', data.userId);
          formData.append('userName', data.userName);
          formData.append('profiles', data.profiles);
          formData.append('userImg', data.userImg);
          formData.append('userPhone', data.userPhone);
          formData.append('gender', data.gender);
          formData.append('locationId', data.locationId);
          formData.append('age', data.age);
          formData.append('flag', data.flag);
          return formData;
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }


    /**
     * 偷听
     * @param userId 用户id
     * @param questionUserId 提问用户id
     * @param teacherId 导师id
     * @param questionId 问题id
     * @param listenFee 偷听费用
     * @param answerId 回答内容id 资源id
     * @param answerURL 回答音频连接地址
     * @param listenTime 偷听时间
     * @returns {Promise}
     */
    this.doListen = function (userId, questionUserId, teacherId, questionId, listenFee, answerId, answerURL, listenTime) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'doListen',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "questionUserId": questionUserId,
          "teacherId": teacherId,
          "questionId": questionId,
          "listenFee": listenFee,
          "answerId": answerId,
          "answerURL": answerURL,
          "listenTime": listenTime
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 下载微信资源
     * @param userId 用户id
     * @param mediaId 媒体文件Id
     * @param questionId 问题id
     * @param answerDurtion 回答时长
     * @returns {Promise}
     */
    this.uploadWXResource = function (teacherId, questionId, mediaId, answerTime, answerDurtion) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'wechat/uploadWXResource',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "teacherId": teacherId,
          "questionId": questionId,
          "mediaId": mediaId,
          "answerTime": answerTime,
          "answerDuration": answerDurtion
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取所有的区域数据
     * @returns {Promise}
     */
    this.getAllLocation = function () {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getAllLocation',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 获取我的问答评论列表
     * @param userId 用户id
     * @param pageNum 当前页数
     * @param lastTime 最后更新时间
     * @returns {Promise}
     */
    this.getMyQuestionAppraise = function (userId, pageNum, lastTime) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'getMyQuestionAppraise',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "userId": userId,
          "pageNum": pageNum,
          "lastTime": lastTime
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }

    /**
     * 阅读广告
     * @param advertId 广告id
     *
     *
     * @returns {Promise}
     */
    this.doReadAdvert = function (advertId) {
      var deferred = $q.defer();
      $http({
        url: Constants.api + 'doReadAdvert',
        method: 'POST',
        timeout: Constants.timeout,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        params: {
          "advertId": advertId
        }
      })
        .success(function (data) {
          //业务处理
          deferred.resolve(data);
        })
        .error(function (data, status, headers, config) {
          //业务处理
          deferred.reject(data)
        })
      return deferred.promise;
    }
  });
