angular.module('starter', ['ionic', 'starter.myCommentsService', 'starter.apiService', 'starter.utilService', 'starter.config', 'starter.filter', 'starter.interceptor'])

  .run(function ($ionicPlatform, $rootScope, $ionicLoading,$http,Constants) {
    var deviceWidth = document.documentElement.clientWidth;
    var proportion = 20 / 750;
    if (deviceWidth > 750) deviceWidth = 750;
    if ($ionicPlatform.is("android")) {
      deviceWidth = deviceWidth * 375 / 360;
      document.documentElement.style.fontSize = deviceWidth * proportion + 'px';
    } else {
      document.documentElement.style.fontSize = deviceWidth * proportion + 'px';
    }
    $rootScope.$on("loading:show", function () {
      $ionicLoading.show({
        templateUrl: '../../templates/loading.html'
      });
      //$ionicLoading.show({template: 'Loading...'});
    });
    $rootScope.$on("loading:hide", function () {
      $ionicLoading.hide();
    });

    $ionicPlatform.ready(function () {
      // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
      // for form inputs)
      if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
        cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        cordova.plugins.Keyboard.disableScroll(true);

      }
      if (window.StatusBar) {
        // org.apache.cordova.statusbar required
        StatusBar.styleDefault();
      }
    });
    //网络请求全局配置
    $http.defaults.headers.get = {
      'user-appid': Constants.userAppId,
      'user-token': Constants.userToken
    };
    $http.defaults.headers.post = {
      'user-appid': Constants.userAppId,
      'user-token': Constants.userToken
    };
    $http.defaults.headers.put = {
      'user-appid': Constants.userAppId,
      'user-token': Constants.userToken
    };
    $http.defaults.headers.detele = {
      'user-appid': Constants.userAppId,
      'user-token': Constants.userToken
    };
  })

  .config(function ($ionicConfigProvider,$httpProvider) {

    $ionicConfigProvider.platform.ios.tabs.style('standard');
    $ionicConfigProvider.platform.ios.tabs.position('bottom');
    $ionicConfigProvider.platform.android.tabs.style('standard');
    $ionicConfigProvider.platform.android.tabs.position('bottom');

    $ionicConfigProvider.platform.ios.navBar.alignTitle('center');
    $ionicConfigProvider.platform.android.navBar.alignTitle('center');

    $ionicConfigProvider.platform.ios.backButton.previousTitleText('').icon('ion-ios-arrow-thin-left');
    $ionicConfigProvider.platform.android.backButton.previousTitleText('').icon('ion-android-arrow-back');

    $ionicConfigProvider.platform.ios.views.transition('ios');
    $ionicConfigProvider.platform.android.views.transition('android');

    $ionicConfigProvider.platform.ios.scrolling.jsScrolling(true);
    $ionicConfigProvider.platform.android.scrolling.jsScrolling(true);

    //添加http请求拦截器
    $httpProvider.interceptors.push('httpInterceptor');

  })
  .controller('myCommentsController', function ($scope, $ionicHistory, myCommentsService, $ionicPlatform,$rootScope,utilService,$ionicScrollDelegate ) {
    $scope.showloading = true;
    $scope.showMoreloading = false;

    myCommentsService.init();
    $rootScope.$broadcast('loading:show');
    if (myCommentsService.isShowMutiAppraise()) {
      myCommentsService.getTopMutiAppraiseList();
    } else {
      myCommentsService.getTopQuestionAppraiseList();
    }

    //数据改变广播
    $scope.$on('appraiseListData.Updated', function () {
      $scope.showloading = false;
      $scope.showMoreloading = false;
      $scope.mutiAppraiseListData = myCommentsService.getMutiAppraiseListData();
      $scope.questionAppraiseListData = myCommentsService.getQuestionAppraiseListData();
      //取消刷新数据
      $scope.$broadcast('scroll.refreshComplete');
      //取消加载更多数据
      $scope.$broadcast('scroll.infiniteScrollComplete');
      $rootScope.$broadcast('loading:hide');
    });

    //下拉更新
    $scope.doRefresh = function () {
      $scope.showloading = false;
      if (myCommentsService.isShowMutiAppraise()) {
        myCommentsService.getTopMutiAppraiseList();
      } else {
        myCommentsService.getTopQuestionAppraiseList();
      }
    }

    //上拉加载更多
    $scope.loadMore = function () {
      $scope.showMoreloading = true;
      if (myCommentsService.isShowMutiAppraise()) {
        myCommentsService.getMoreMutiAppraiseList();
      } else {
        myCommentsService.getMoreQuestionAppraiseList();
      }
    }
    //判断是否有下页数据
    $scope.hasNextPage = function () {
      return myCommentsService.hasNextPage();
    };

    //判断是否有数据
    $scope.hasData = function () {
      return $scope.showloading || myCommentsService.hasData();
    };

    /**
     * 获取用户id
     */
    $scope.getUserId = function () {
      return utilService.getUserId();
    }

    /**
     * 改变tab
     * @param type tab类型 0:视频评论 1:问题评论
     */
    $scope.changeTab = function (type) {
      switch (type) {
        case 0:
          //显示视频评论
          if (myCommentsService.getShowType() != 0) {
            $rootScope.$broadcast('loading:show');
            myCommentsService.setMutiAppraiseListData(undefined);
            myCommentsService.setShowType(0);
            $scope.showloading = true;
            setTypeStyle();
            $ionicScrollDelegate.$getByHandle('scrollHandle').resize();
            myCommentsService.getTopMutiAppraiseList();
          }
          break;
        case 1:
          //显示问题评论
          if (myCommentsService.getShowType() != 1) {
            $rootScope.$broadcast('loading:show');
            myCommentsService.setQuestionAppraiseListData(undefined);
            myCommentsService.setShowType(1);
            $scope.showloading = true;
            setTypeStyle();
            $ionicScrollDelegate.$getByHandle('scrollHandle').resize();
            myCommentsService.getTopQuestionAppraiseList();
          }
          break;
        default:
          break;
      }
    }

    /**
     * 是否显示视频评论信息
     */
    $scope.isShowMutiAppraise = function () {
      return myCommentsService.isShowMutiAppraise();
    }

    /**
     * 设置选择样式
     */
    function setTypeStyle() {
      /**显示类型 0视频评论 1问题评论*/
      var showType = myCommentsService.getShowType();
      $("#tab_muti").removeClass("tab_line");
      $("#tab_question").removeClass("tab_line");
      if (showType == 0) {
        $("#tab_muti").addClass("tab_line");
      } else {
        $("#tab_question").addClass("tab_line");
      }
    }

    /**
     * 点击item
     * @param item
     */
    $scope.clickMutiItem = function (item) {
      var type = 0;
      switch (item.mutiType) {
        case "1":
          type = 0;
          break;
        case "2":
          type = 1;
          break;
        case "3":
          type = 2;
          break;
      }

      if ($ionicPlatform.is("android")) {
        window.jsObj.myAppraiseClickItem(item.appraiseSourceId, type, item.muitName, item.mutiUrl);
      }
      if ($ionicPlatform.is("ios")) {
        myAppraiseClickItem(item.appraiseSourceId, type, item.muitName, item.mutiUrl);
      }
    }

    /**
     * 点击问题评论
     * @param item
     */
    $scope.clickQuestionItem = function (item) {
      if ($ionicPlatform.is("android")) {
        window.jsObj.myQuestionAppraiseClickItem(angular.toJson(item));
      }
      if ($ionicPlatform.is("ios")) {
        myQuestionAppraiseClickItem(item);
      }
    }

  });
