//公共方法
angular.module("starter.utilService", [])
  .service("utilService", function ($rootScope, Constants) {
    //判断是否登录
    this.isLogin = function () {
      var userId = this.getQueryUrlString("userId");
      if (userId === undefined || userId == "" || userId == "\"\"") {
        return false;
      } else {
        return true;
      }
    }
    //获取登录用户id
    this.getUserId = function () {
      if (this.isLogin()) {
        return this.getQueryUrlString("userId");
      } else {
        return "";
      }
    }
    /**
     * 获取完整url路径
     * @param url
     * @returns {*}
     */
    this.getFullUrl = function (url) {
      if (url === undefined || url == null || url == "") {
        return "";
      } else {
        if (url.indexOf("http://") < 0 && url.indexOf("https://") < 0) {
          var resourceUrl = this.getQueryUrlString("resourceUrl");
          if (resourceUrl == undefined || resourceUrl.length == 0) {
            return Constants.resourceApi + url;
          } else {
            return resourceUrl + url;
          }
        } else {
          return url;
        }
      }
    }
    /***
     * 获取url的参数
     * @param nanme 参数名称
     * @returns {string} 参数值 没有获取到返回空字符串
     */
    this.getQueryUrlString = function (name) {
      var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
      var r = window.location.search.substr(1).match(reg);
      if (r != null)return unescape(r[2]);
      return "";
    }

    /**
     * 获取默认的当前时间格式
     */
    this.getDefaultCurrentDate = function () {
      return new Date().Format("yyyy-MM-dd");
    }
    /**
     * 获取格式化的当前时间
     * @param format yyyy-MM-dd hh:mm:ss.S
     */
    this.getFormatCurrentDate = function (format) {
      return new Date().Format(format);
    }

    this.getDateTimeBefore = function (input, param) {
      //方法后期实现
      if (input === undefined || input == null || input.length < 14) {
        return input;
      } else {
        var oldDate = new Date();
        oldDate.setYear(parseInt(input.substring(0, 4)));
        oldDate.setDate(1);
        oldDate.setMonth(parseInt(input.substring(4, 6)) - 1);
        oldDate.setDate(parseInt(input.substring(6, 8)));
        oldDate.setHours(parseInt(input.substring(8, 10)))
        oldDate.setMinutes(parseInt(input.substring(10, 12)));
        oldDate.setSeconds(parseInt(input.substring(12, 14)));
        var result;
        var minute = 1000 * 60;
        var hour = minute * 60;
        var day = hour * 24;
        var halfamonth = day * 15;
        var month = day * 30;
        var now = new Date();
        if (param != undefined && param != null && param.length >= 14) {
          now.setYear(parseInt(param.substring(0, 4)));
          now.setDate(1);
          now.setMonth(parseInt(param.substring(4, 6)) - 1);
          now.setDate(parseInt(param.substring(6, 8)));
          now.setHours(parseInt(param.substring(8, 10)))
          now.setMinutes(parseInt(param.substring(10, 12)));
          now.setSeconds(parseInt(param.substring(12, 14)));
        }
        var diffValue = now.getTime() - oldDate.getTime();
        if (diffValue < 0) {
          return input;
        }
        var monthC = diffValue / month;
        var weekC = diffValue / (7 * day);
        var dayC = diffValue / day;
        var hourC = diffValue / hour;
        var minC = diffValue / minute;
        if (monthC >= 1) {
          //result = "" + parseInt(monthC) + "月前";
          result = input.substring(0, 4) + "-" + input.substring(4, 6) + "-" + input.substring(6, 8);
        }
        else if (weekC >= 1) {
          if (weekC == 1) {
            result = "" + parseInt(weekC) + "周前";
          } else {
            result = input.substring(0, 4) + "-" + input.substring(4, 6) + "-" + input.substring(6, 8);
          }
        }
        else if (dayC >= 1) {
          result = "" + parseInt(dayC) + "天前";
        }
        else if (hourC >= 1) {
          result = "" + parseInt(hourC) + "小时前";
        }
        else if (minC >= 1) {
          result = "" + parseInt(minC) + "分钟前";
        } else
          result = "刚刚";
        return result;
      }
    }

    /**
     * 把list的数据转换为grid的数据
     * @param resourceData 要转换的数据
     * @param colCount 每行列的个数
     * @returns {Array} 格式化的数据
     * @constructor
     */
    this.formatListDataToGrid = function (resourceData, colCount) {
      if (resourceData === undefined || resourceData.length == 0) {
        return [];
      } else {
        var returnData = [];
        var dataLength = resourceData.length;
        var returnDataLength = dataLength % colCount == 0 ? dataLength / colCount : parseInt(dataLength / colCount) + 1;
        for (var i = 0; i < returnDataLength; i++) {
          var itemData = [];
          for (var j = 0; j < colCount; j++) {
            var secondItemData = {};
            secondItemData.index = i * colCount + j;
            secondItemData.data = resourceData[secondItemData.index];
            itemData.push(secondItemData);
            if (secondItemData.index == dataLength - 1) {
              break;
            }
          }
          returnData.push(itemData);
        }
        return returnData;
      }
    }

    /**
     * 判断数据是否为空
     * @param data
     * @returns {boolean}
     */
    this.isNull = function (data) {
      if (data === undefined || data == null || data.length == 0) {
        return true;
      }
      return false;
    }

    /**
     * 验证是否为手机
     * @param phone
     * @returns {boolean}
     */
    this.isPhone = function (phone) {
      //var reg = /^(((13[0-9]{1})|(15[0-9]{1})|(18[0-9]{1}))+\d{8})$/;
      var reg = /^((1[3,5,7,8][0-9])|(14[5,7])|(17[0,6,7,8]))+\d{8}$/;
      if (!reg.test(phone)) {
        return false;
      }
      return true;
    }
    /**
     * 验证是否为密码
     *  @returns {boolean}
     * @param psd
     */
    this.isPsd = function (psd) {
      /*var reg = /^[0-9a-zA-Z]{6,19}$/;
       if (!reg.test(phone)) {
       return false;
       }*/
      return true;
    }

    /**
     * 获取随机验证码
     * @returns {string}
     */
    this.getRandomCode = function () {
      var code = Math.floor(Math.random() * 10000);
      while (true) {
        if (code < 1000) {
          code = Math.floor(Math.random() * 10000);
        } else {
          break;
        }
      }
      return code;
    }
  });
